QDiction
============

Author
======
Rasaq O Alli

About
=====
**QDiction** is a lightweight minimal dictionary based on wordnet provided by https://wordnet.princeton.edu and language processing 
toolkit is sourced from https://www.nltk.org/. Search results are classified (where appropriate) as antonyms,
synonyms or related words.


Installation
============
On a linux computer with python3.6+ and pip, installation is as simple as running "pip install qdiction". 


Usage
=====
After a successful installation, the app can be launched using "python -m qdiction". 


Useful information
==================

On the first run qdiction will download the "wordnet" file and save
it in the user's home directory. It will be installed in a folder
named "nltk_data". Therefore, if you later wish to uninstall
qdiction, **first** use
"pip uninstall qdiction" and **second** remove the nltk_data folder from
your home directory.


Contributing
============

Please submit bug reports and issues to
`github issues <https://github.com/roalli88/QDICTION/issues>_`
